# Generated by roxygen2: do not edit by hand

export(has_sixel_support)
export(has_tgp_support)
export(is_ghostty)
export(is_kitty)
export(is_nvim)
export(is_tmux)
export(is_vim)
export(kitty_background)
export(kitty_colors)
export(kitty_foreground)
export(kitty_palette)
export(png2sixel)
export(png2terminal)
export(png2tgp)
export(raster2sixel)
export(raster2terminal)
export(raster2tgp)
export(sixel)
export(term_background)
export(term_color_mode)
export(term_dim)
export(term_foreground)
export(term_height)
export(term_palette)
export(term_replot)
export(term_width)
export(tgp)
importFrom(Rcpp,sourceCpp)
importFrom(base64enc,base64encode)
useDynLib(terminalgraphics, .registration = TRUE)
