# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

term_color_mode_rcpp <- function(dsr = TRUE) {
    .Call(`_terminalgraphics_term_color_mode_rcpp`, dsr)
}

query_sixel_support_rcpp <- function(tmux) {
    .Call(`_terminalgraphics_query_sixel_support_rcpp`, tmux)
}

query_tgp_support_rcpp <- function() {
    .Call(`_terminalgraphics_query_tgp_support_rcpp`)
}

screen_dim_cpp <- function() {
    .Call(`_terminalgraphics_screen_dim_cpp`)
}

